@@ -3,6 +3,7 @@ from bobtemplates.plone.base import base_prepare_renderer
 from bobtemplates.plone.base import echo
 from bobtemplates.plone.base import git_commit
 from bobtemplates.plone.base import update_file
+from bobtemplates.plone.utils import run_black
 from bobtemplates.plone.utils import run_isort
 from lxml import etree
 
@@ -11,7 +12,7 @@ import os
 
 
 def _update_package_configure_zcml(configurator):
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     file_path = configurator.variables["package_folder"] + "/" + file_name
     nsprefix = "{http://namespaces.zope.org/zope}"
 
@@ -37,7 +38,7 @@ def _update_package_configure_zcml(configurator):
 
 
 def _update_behaviors_configure_zcml(configurator):
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     file_path = configurator.variables["package_folder"] + "/behaviors/" + file_name
     example_file_path = file_path + ".example"
     file_list = os.listdir(os.path.dirname(file_path))
@@ -99,6 +100,7 @@ def post_renderer(configurator):
     _update_package_configure_zcml(configurator)
     _update_behaviors_configure_zcml(configurator)
     run_isort(configurator)
+    run_black(configurator)
     git_commit(
         configurator,
         "Add behavior: {0}".format(
