@@ -4,6 +4,7 @@ from bobtemplates.plone.base import base_prepare_renderer
 from bobtemplates.plone.base import git_commit
 from bobtemplates.plone.base import remove_unwanted_files
 from bobtemplates.plone.base import update_configure_zcml
+from bobtemplates.plone.utils import run_black
 from bobtemplates.plone.utils import run_isort
 from lxml import etree
 
@@ -24,7 +25,7 @@ def _update_package_configure_zcml(configurator):
     path = "{0}".format(
         configurator.variables["package_folder"],
     )
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     match_xpath = "include[@package='.api']"
     match_str = "-*- extra stuff goes here -*-"
     insert_str = """
@@ -44,7 +45,7 @@ def _update_api_configure_zcml(configurator):
     path = "{0}/api".format(
         configurator.variables["package_folder"],
     )
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     example_file_name = "{0}.example".format(file_name)
     match_xpath = "zope:include[@package='.services']"
     match_str = "-*- extra stuff goes here -*-"
@@ -66,7 +67,7 @@ def _update_services_configure_zcml(configurator):
     path = "{0}/api/services".format(
         configurator.variables["package_folder"],
     )
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     example_file_name = "{0}.example".format(file_name)
     match_xpath = "zope:include[@package='.{0}']".format(
         configurator.variables["service_class_name_normalized"],
@@ -90,8 +91,8 @@ def _update_metadata_xml(configurator):
     """Add plone.restapi dependency metadata.xml in
     Generic Setup profiles.
     """
-    metadata_file_name = u"metadata.xml"
-    metadata_file_dir = u"profiles/default"
+    metadata_file_name = "metadata.xml"
+    metadata_file_dir = "profiles/default"
     metadata_file_path = (
         configurator.variables["package_folder"]
         + "/"
@@ -168,6 +169,7 @@ def post_renderer(configurator):
     _update_metadata_xml(configurator)
     _remove_unwanted_files(configurator)
     run_isort(configurator)
+    run_black(configurator)
     git_commit(
         configurator,
         "Add restapi_service: {0}".format(
