@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
-import os
-
-import pytest
+from bobtemplates.plone import base
 from mrbob.bobexceptions import ValidationError
 from mrbob.configurator import Configurator
 
-from bobtemplates.plone import base
+import os
+import pytest
 
 
 def test_to_boolean():
@@ -24,12 +23,15 @@ def test_check_klass_name():
 
     with pytest.raises(ValidationError):
         hookit("import")
-    with pytest.raises(ValidationError):
-        hookit("süpertype")
+    # Python 3.0 introduces additional characters from outside the ASCII range (see PEP 3131).
+    # with pytest.raises(ValidationError):
+    #     hookit("süpertype")
     with pytest.raises(ValidationError):
         hookit("2ndComing")
     with pytest.raises(ValidationError):
         hookit("*sterisk")
+    with pytest.raises(ValidationError):
+        hookit("da-sh")
     assert hookit("Supertype") == "Supertype"
     assert hookit("second_coming") == "second_coming"
 
@@ -333,6 +335,30 @@ def test_validate_packagename(tmpdir):
     )
     base.validate_packagename(configurator)
 
+    # step 10: invalid identifier
+    with pytest.raises(SystemExit):
+        configurator = Configurator(
+            template="bobtemplates.plone:addon",
+            target_directory=os.path.join(base_path, "1collective.foo"),
+        )
+        base.validate_packagename(configurator)
+
+    # step 10b: invalid identifier
+    with pytest.raises(SystemExit):
+        configurator = Configurator(
+            template="bobtemplates.plone:addon",
+            target_directory=os.path.join(base_path, "collective.1foo"),
+        )
+        base.validate_packagename(configurator)
+
+    # step 10c: invalid identifier
+    with pytest.raises(SystemExit):
+        configurator = Configurator(
+            template="bobtemplates.plone:addon",
+            target_directory=os.path.join(base_path, "collective.def"),
+        )
+        base.validate_packagename(configurator)
+
 
 def test_pre_username():
     # step 1: test None
