@@ -15,43 +15,54 @@ def test_prep_renderer(tmpdir):
     package_root = tmpdir.strpath + "/collective.todo"
     init_package_base_structure(package_root)
     configurator = Configurator(
-        template='bobtemplates.plone:svelte_app',
+        template="bobtemplates.plone:svelte_app",
         target_directory=package_root,
         variables={
-            'svelte_app_name': 'my-cool-svelte-app',
+            "svelte_app_name": "my-cool-svelte-app",
         },
     )
     svelte_app.pre_renderer(configurator)
 
 
 def test_check_name(tmpdir):
-    target_path = tmpdir.strpath + '/collective.todo'
-    question = Question(name="svelte_app_name", question="Name of your Svelte app", default=None)
+    target_path = tmpdir.strpath + "/collective.todo"
+    question = Question(
+        name="svelte_app_name", question="Name of your Svelte app", default=None
+    )
     configurator = Configurator(
-        template='bobtemplates.plone:svelte_app',
+        template="bobtemplates.plone:svelte_app",
         target_directory=target_path,
         bobconfig={"non_interactive": True},
     )
     with pytest.raises(ValidationError):
-        svelte_app.check_name(configurator, question, 'My-Svelteapp')
+        svelte_app.check_name(configurator, question, "My-Svelteapp")
     with pytest.raises(ValidationError):
-        svelte_app.check_name(configurator, question, 'MySvelteApp')
+        svelte_app.check_name(configurator, question, "MySvelteApp")
     with pytest.raises(ValidationError):
-        svelte_app.check_name(configurator, question, 'mysvelteapp')
+        svelte_app.check_name(configurator, question, "mysvelteapp")
     with pytest.raises(ValidationError):
-        svelte_app.check_name(configurator, question, 'my_svelteapp')
+        svelte_app.check_name(configurator, question, "my_svelteapp")
     with pytest.raises(ValidationError):
-        svelte_app.check_name(configurator, question, 'my_svelte_app')
-    assert svelte_app.check_name(configurator, question, 'my-app') == 'my-app'
-    assert svelte_app.check_name(configurator, question, 'my-svelte-app') == 'my-svelte-app'
-    assert svelte_app.check_name(configurator, question, 'my-cool-svelte-app') == 'my-cool-svelte-app'
-    assert svelte_app.check_name(configurator, question, 'my-cool-svelte-app-one') == 'my-cool-svelte-app-one'
+        svelte_app.check_name(configurator, question, "my_svelte_app")
+    assert svelte_app.check_name(configurator, question, "my-app") == "my-app"
+    assert (
+        svelte_app.check_name(configurator, question, "my-svelte-app")
+        == "my-svelte-app"
+    )
+    assert (
+        svelte_app.check_name(configurator, question, "my-cool-svelte-app")
+        == "my-cool-svelte-app"
+    )
+    assert (
+        svelte_app.check_name(configurator, question, "my-cool-svelte-app-one")
+        == "my-cool-svelte-app-one"
+    )
 
 
 def test_post_renderer(tmpdir):
-    target_path = tmpdir.strpath + '/collective.todo'
-    package_path = target_path + '/src/collective/todo'
-    profiles_path = package_path + '/profiles/default'
+    target_path = tmpdir.strpath + "/collective.todo"
+    package_path = target_path + "/src/collective/todo"
+    profiles_path = package_path + "/profiles/default"
     os.makedirs(target_path)
     os.makedirs(package_path)
     os.makedirs(profiles_path)
@@ -64,21 +75,21 @@ def test_post_renderer(tmpdir):
   </dependencies>
 </metadata>
 """
-    with open(os.path.join(profiles_path + '/metadata.xml'), 'w') as f:
+    with open(os.path.join(profiles_path + "/metadata.xml"), "w") as f:
         f.write(template)
 
     template = """
 [main]
 version=5.1
 """
-    with open(os.path.join(target_path + '/bobtemplate.cfg'), 'w') as f:
+    with open(os.path.join(target_path + "/bobtemplate.cfg"), "w") as f:
         f.write(template)
 
     template = """
     dummy
     '-*- Extra requirements: -*-'
 """
-    with open(os.path.join(target_path + '/setup.py'), 'w') as f:
+    with open(os.path.join(target_path + "/setup.py"), "w") as f:
         f.write(template)
 
     template = """
@@ -92,18 +103,18 @@ version=5.1
 
     </configure>
 """
-    with open(os.path.join(package_path + '/configure.zcml'), 'w') as f:
+    with open(os.path.join(package_path + "/configure.zcml"), "w") as f:
         f.write(template)
     configurator = Configurator(
-        template='bobtemplates.plone:svelte_app',
+        template="bobtemplates.plone:svelte_app",
         target_directory=target_path,
         bobconfig={
-            'non_interactive': True,
+            "non_interactive": True,
         },
         variables={
-            'plone.version': '5.2',
-            'svelte_app_name': 'my-cool-svelte-app',
-            'svelte_app_custom_element': True,
+            "plone.version": "5.2",
+            "svelte_app_name": "my-cool-svelte-app",
+            "svelte_app_custom_element": True,
         },
     )
 
